==> haskell-checkers-0.6.0-248-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-L81NI313lDV31vlyYGRUbJ
key:                  checkers-0.6.0-L81NI313lDV31vlyYGRUbJ
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  5d165b33c9f285a55e5bfdcf1b78543c
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-L81NI313lDV31vlyYGRUbJ
depends:
    QuickCheck-2.15.0.1-5wgMd498nCWIkHPGslLJlo array-0.5.4.0
    base-4.17.2.1 random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.6.0-253-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-HsAsEgdOn91q1APRg8pOS
key:                  checkers-0.6.0-HsAsEgdOn91q1APRg8pOS
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  cc718f6df60430e9c5d337b4ab348fe9
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/checkers-0.6.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-HsAsEgdOn91q1APRg8pOS
depends:
    QuickCheck-2.15.0.1-Lq4ECkPzV8iDkKvRhPZIAs array-0.5.8.0
    base-4.18.3.0 random-1.2.1.3-GswEfj1SZ276IcAtylwQ0f
    semigroupoids-6.0.1-HDr1Vl4bsU6CmLVz8mRz3I

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
